@@ -9,15 +9,14 @@ use Moo;
 use Fcntl qw/ O_NONBLOCK O_RDONLY /;
 use List::Util 1.29 qw/ pairmap pairs /;
 use Math::Random::ISAAC;
-use Ref::Util qw/ is_plain_arrayref /;
-use Types::Standard qw/ ArrayRef Bool HashRef Str /;
+use Types::Standard qw/ ArrayRef is_ArrayRef Bool HashRef Str /;
 
 # RECOMMEND PREREQ: Math::Random::ISAAC::XS
-# RECOMMEND PREREQ: Ref::Util::XS
+# RECOMMEND PREREQ: Type::Tiny::XS
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 has _base_policy => (
@@ -65,7 +64,7 @@ has nonces_for => (
     is      => 'lazy',
     isa     => ArrayRef [Str],
     builder => sub { return [] },
-    coerce  => sub { my $val = is_plain_arrayref( $_[0] ) ? $_[0] : [ $_[0] ] },
+    coerce  => sub { my $val = is_ArrayRef( $_[0] ) ? $_[0] : [ $_[0] ] },
 );
 
 
@@ -92,9 +91,10 @@ sub _build_nonce {
 
 
 has header => (
-    is      => 'lazy',
-    isa     => Str,
-    clearer => '_clear_header',
+    is       => 'lazy',
+    isa      => Str,
+    clearer  => '_clear_header',
+    init_arg => undef,
 );
 
 sub _build_header {
@@ -164,7 +164,7 @@ HTTP::CSPHeader - manage dynamic content security policy headers
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -247,7 +247,9 @@ you can override the C<_build_nonce> method in a subclass.
 
 =head2 header
 
-This is the value of the header.
+This is the value of the header, generated from the L</policy>.
+
+This is a read-only accessor.
 
 =head1 METHODS
 
